<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>Apollonius</name>
    <message>
        <location filename="../Apollonius.js" line="+1769"/>
        <source>Invalid radius</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+51"/>
        <source>No solution</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DefaultAction</name>
    <message>
        <location filename="../DefaultAction.js" line="+89"/>
        <source>Select entity or region</source>
        <translation>Valitse kohde tai alue</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Move entity or reference</source>
        <translation>Siirrä kohde tai viite</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Set second corner</source>
        <translation>Aseta toinen kulma</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Specify target point of reference point</source>
        <translation>Määrittele kohdepiste tai viitepiste</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Specify target point of selection</source>
        <translation>Määrittele valinnan kohdepiste</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Move entity to desired location</source>
        <translation>Siirrä kohde haluttuun paikkaan</translation>
    </message>
    <message>
        <location line="+376"/>
        <source>Move Reference Point</source>
        <translation>Siirrä viite</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Move Selection</source>
        <translation>Siirrä valinta</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Move Entity</source>
        <translation>Siirrä kohde</translation>
    </message>
    <message>
        <location line="+127"/>
        <source>Editing block &apos;%1&apos;&lt;br&gt;Choose &lt;i&gt;Block &gt; Return to Main Drawing&lt;/i&gt; when done</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EAction</name>
    <message>
        <location filename="../EAction.js" line="+64"/>
        <source>Back</source>
        <translation>Takaisin</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+2075"/>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <location line="-1802"/>
        <location line="+136"/>
        <source>Active Tool:</source>
        <translation>Aktiivinen työkalu:</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>None</source>
        <translation>Ei mitään</translation>
    </message>
    <message>
        <location line="+662"/>
        <source>Options</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <source>Block Options</source>
        <translation type="vanished">Lohkoasetukset</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Main Tools</source>
        <translation>Päätyökalut</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>CAD Tools</source>
        <translation>CAD työkalut</translation>
    </message>
    <message>
        <location line="+710"/>
        <source>Entity is on a locked layer.</source>
        <translation>Kohde on lukitussa tasossa.</translation>
    </message>
    <message>
        <location line="+232"/>
        <source>Length:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Entity is not a block reference.</source>
        <translation>Kohde ei ole lohkoviite.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line or arc.</source>
        <translation>Kohde ei ole viiva tai kaari.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc or polyline.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line.</source>
        <translation>Kohde ei ole viiva.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not an arc or circle.</source>
        <translation>Kohde ei ole kaari tai ympyrä.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc or circle.</source>
        <translation>Kohde ei ole viiva, kaari tai ympyrä.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not an arc, circle or ellipse.</source>
        <translation>Kohde ei ole kaari, ympyrä tai ellipsi.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle or ellipse.</source>
        <translation>Kohde ei ole viiva, kaari, ympyrä tai ellipsi.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle, ellipse or polyline.</source>
        <translation>Kohde ei ole viiva, kaari, ympyrä, ellipsi tai moniviiva.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle, ellipse or spline.</source>
        <translation>Kohde ei ole viiva, kaari, ympyrä, ellipsi tai käyrä.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle, ellipse, spline or polyline.</source>
        <translation>Kohde ei ole viiva, kaari, ympyrä, ellipsi, käyrä tai moniviiva.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a polyline.</source>
        <translation>Kohde ei ole moniviiva.</translation>
    </message>
</context>
<context>
    <name>ShapeAlgorithms</name>
    <message>
        <source>Radius dropped below 0.0 after %1 concentric circle(s).</source>
        <translation type="vanished">Säde on pudonnut alle 0.0 arvon %1 samankeskisen ympyrän (ympyröiden) jälkeen.</translation>
    </message>
    <message>
        <source>Radius dropped below 0.0 after %1 concentric arc(s).</source>
        <translation type="vanished">Säde on pudonnut alle 0.0 arvon %1 samankeskisen kaaren (kaarien) jälkeen.</translation>
    </message>
    <message>
        <location filename="../ShapeAlgorithms.js" line="+1413"/>
        <location line="+29"/>
        <source>At least two points are identical.</source>
        <translation>Vähintään kaksi pistettä ovat samat.</translation>
    </message>
    <message>
        <location line="-22"/>
        <source>No circle possible.</source>
        <translation>Ympyrä ei mahdollinen.</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>No arc possible.</source>
        <translation>Kaari ei mahdollinen.</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Invalid number of segments: %1.</source>
        <translation>Virheellinen määrä segmenttejä %1.</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Invalid ellipse major / minor: %1 / %2.</source>
        <translation>Puutteellinen ellipsi, suurempi / pienempi: %1 / %2.</translation>
    </message>
</context>
<context>
    <name>WidgetFactory</name>
    <message>
        <location filename="../WidgetFactory.js" line="+1003"/>
        <source>Restore defaults</source>
        <translation>Palauta oletusarvot</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Insert Symbol</source>
        <translation>Lisää erikoismerkki</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Diameter</source>
        <translation>Halkaisija</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arc</source>
        <translation type="unfinished">Kaari</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Degree</source>
        <translation>Aste</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plus/Minus</source>
        <translation>Plus/miinus</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Almost equal to</source>
        <translation>Lähes yhtäsuuri kuin</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Asymptotically equal to</source>
        <translation>Asymptoottisesti yhtäsuuri kuin</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pi</source>
        <translation>Pii</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Square root</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Phi</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>phi</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Alt phi</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Ohm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>omega</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Multiplication</source>
        <translation>Kertolasku</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Division</source>
        <translation>Jakolasku</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Square</source>
        <translation>Neliö</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Delta</source>
        <translation>Delta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Stacked text</source>
        <translation>Pinottu teksti</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Measured value</source>
        <translation>Mitattu arvo</translation>
    </message>
    <message>
        <location line="+116"/>
        <source>Left</source>
        <translation>Vasen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Center</source>
        <translation>Keski</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Right</source>
        <translation>Oikea</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Aligned</source>
        <translation>Tasattu</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+7"/>
        <source>Middle</source>
        <translation>Keskellä</translation>
    </message>
    <message>
        <location line="-6"/>
        <source>Fit</source>
        <translation>Sovita</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Top</source>
        <translation>Ylä</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Base</source>
        <translation>Perus</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bottom</source>
        <translation>Ala</translation>
    </message>
    <message>
        <location line="+7"/>
        <location line="+4"/>
        <source>Clockwise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-3"/>
        <location line="+4"/>
        <source>Counterclockwise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Preceding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Above</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>None</source>
        <translation type="unfinished">Ei mitään</translation>
    </message>
</context>
<context>
    <name>autostart</name>
    <message>
        <location filename="../autostart.js" line="+327"/>
        <source>Loading add-on translations...</source>
        <translation>Lataamassa lisäosia käännökseen...</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>Loading add-ons...</source>
        <translation>Lataamassa lisäosia...</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Initializing add-ons...</source>
        <translation>Määrittelemässä lisäosia...</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Initializing add-ons:</source>
        <translation>Alustetaan lisäosat:</translation>
    </message>
    <message>
        <source>Post-initializing add-ons...</source>
        <translation type="vanished">Jälki-alustetaan lisäosat...</translation>
    </message>
</context>
<context>
    <name>library</name>
    <message>
        <location filename="../library.js" line="+829"/>
        <source>Objects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Object</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Unknown Objects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Unknown Object</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Blocks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Block</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Layers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Layer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Layouts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Layout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Linetypes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Linetype</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Views</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+0"/>
        <source>View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Entity</source>
        <translation>Kohde</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Entities</source>
        <translation>Kohteet</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>3dFaces</source>
        <translation>3d pinnat</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>3dFace</source>
        <translation>3d pinta</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block References</source>
        <translation>Lohkoviitteet</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Block Reference</source>
        <translation>Lohkoviite</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block References and Attributes</source>
        <translation>Lohkoviitteet ja ominaisuudet</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Block Reference and Attributes</source>
        <translation>Lohkoviitteet ja ominaisuudet</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Arcs</source>
        <translation>Kaaret</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Arc</source>
        <translation>Kaari</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Attributes</source>
        <translation>Ominaisuudet</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Attribute</source>
        <translation>Ominaisuus</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Attribute Definitions</source>
        <translation>Ominaisuuksien määrittely</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Attribute Definition</source>
        <translation>Ominaisuuksien määrittely</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Circles</source>
        <translation>Ympyrät</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Circle</source>
        <translation>Ympyrä</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Dimensions</source>
        <translation>Mitat</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Dimension</source>
        <translation>Mitta</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Aligned Dimensions</source>
        <translation>Tasatut mitat</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Aligned Dimension</source>
        <translation>Tasattu mitta</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Angular Dimensions</source>
        <translation>Kulmamitat</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Angular Dimension</source>
        <translation>Kulmamitta</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>2 Line Angular Dimensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+0"/>
        <source>2 Line Angular Dimension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>3 Point Angular Dimensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+0"/>
        <source>3 Point Angular Dimension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Arc Dimension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Diametric Dimensions</source>
        <translation>Halkaisijan mitat</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Diametric Dimension</source>
        <translation>Halkaisijan mitta</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Ordinate Dimensions</source>
        <translation>Y-ordinaatan mitat</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Ordinate Dimension</source>
        <translation>Ordinaatan mitta</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Rotated Dimensions</source>
        <translation>Kierretyt mitat</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Rotated Dimension</source>
        <translation>Kierretty mitta</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Radial Dimensions</source>
        <translation>Säteittäiset mitat</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Radial Dimension</source>
        <translation>Säteittäinen mitta</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Ellipses</source>
        <translation>Ellipsit</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Ellipse</source>
        <translation>Ellipsi</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Hatches</source>
        <translation>Luukut</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Hatch</source>
        <translation>Luukku</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Images</source>
        <translation>Kuvat</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Image</source>
        <translation>Kuva</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Leaders</source>
        <translation>Perusviivat</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Leader</source>
        <translation>Perusviiva</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Lines</source>
        <translation>Viivat</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Line</source>
        <translation>Viiva</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Infinite Lines</source>
        <translation>Äärettömät viivat</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Infinite Line</source>
        <translation>Ääretön viiva</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Rays</source>
        <translation>Säteet</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Ray</source>
        <translation>Säde</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Points</source>
        <translation>Pisteet</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Point</source>
        <translation>Piste</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Polylines</source>
        <translation>Murtoviivat</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Polyline</source>
        <translation>Moniviiva</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Solids</source>
        <translation>Kiinteät</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Solid</source>
        <translation>Kiinteä</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Traces</source>
        <translation>Jäljet</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Trace</source>
        <translation>Jälki</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Faces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Face</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Splines</source>
        <translation>Käyrät</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Spline</source>
        <translation>Käyrä</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Text based</source>
        <translation>Tekstiin perustuva</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Texts</source>
        <translation>Tekstit</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Text</source>
        <translation>Teksti</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Viewports</source>
        <translation>Näkymät</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Viewport</source>
        <translation>Näkymä</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Unknown Entities</source>
        <translation>Tuntematon kohteet</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Unknown Entity</source>
        <translation>Tuntematon kohde</translation>
    </message>
</context>
<context>
    <name>simple_modify</name>
    <message>
        <location filename="../simple_modify.js" line="+301"/>
        <source>First entity cannot be trimmed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Entity cannot be trimmed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Second entity cannot be trimmed.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
